@@ -4,7 +4,7 @@ package POE::Component::ElasticSearch::Indexer;
 use strict;
 use warnings;
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use Const::Fast;
 use Digest::SHA1 qw(sha1_hex);
@@ -164,7 +164,7 @@ sub _stats {
     $heap->{stats} = {};
 
     # Fetch the pending request count from the HTTP client
-    $stats->{pending_requests} = $kernel->call( http => 'pending_request_count' );
+    $stats->{pending_requests} = $kernel->call( http => 'pending_requests_count' );
 
     # Check and set readiness
     $heap->{es_ready} = $stats->{pending_requests} < $heap->{cfg}{MaxPendingRequests};
@@ -582,7 +582,7 @@ POE::Component::ElasticSearch::Indexer - POE session to index data to ElasticSea
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
